@@ -9,7 +9,7 @@ use File::Spec;
 use File::Find;
 use Cwd ();
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 sub new {
   my ($class, $root, $opts) = @_;
@@ -17,14 +17,20 @@ sub new {
     $opts = $root; $root = undef;
   }
   $opts ||= {};
+  $opts->{DISTROOT} = $root;
   bless $opts, $class;
 }
 
 # adapted from PAUSE::mldistwatch#check_for_new
 sub parse {
   my ($self, $root) = @_;
-  $self->{DISTROOT} = $self->{DIST} = $root ||= Cwd::cwd();
+  if ($root) {
+    $self->{DISTROOT} = $root;
+  } elsif (!$self->{DISTROOT}) {
+    $self->{DISTROOT} = Cwd::cwd();
+  }
 
+  $self->{DIST} = $self->{DISTROOT};
   $self->_read_dist;
   $self->_extract_meta;
   $self->_examine_pms;
